---
title: <span class="badge object-type-enum"></span> PieChartType
---
# <span class="badge object-type-enum"></span> PieChartType

Select the pie chart display style.

## Definition

```python
class PieChartType(enum.StrEnum):
    """
    Select the pie chart display style.
    """

    PIE = "pie"
    DONUT = "donut"
```
